Module: Pantheios::Globals
- Defined in:
- lib/pantheios/globals.rb
Overview
A utility namespace for the sole purpose of defining "globals" - actually module constants' values and module attributes - that control the behaviour of Pantheios globally
NOTE: The "globals" in this namespace are operative before
::Pantheios::Core and ::Pantheios::API
Variables
-
HAS_CASCADED_INCLUDES [boolean] Determines whether including
::Pantheiosalso includes all relevant parts of subordinate namespaces. See the documentation for the::Pantheiosnamespace for further details -
INITIAL_SERVICE_CLASSES [ svc-class, [ svc-class ] ] Specifies the service class(es) that will be used to create the initial service instance. Ignored if INITIAL_SERVICE_INSTANCES specifies an instance
-
INITIAL_SERVICE_INSTANCES [ svc-instance, [ svc-instance ] ] Specifies the initial service instance
-
MAIN_THREAD_NAME A string specifying the main thread name, or an array containing a thread instance and a string specifying the thread and its name
NOTE: This feature is subject to the initialising threads: if the string form is used then the first initialising thread of Pantheios.Ruby will be the named thread
-
PROCESS_NAME A string specifying the process name, or one of the recognised symbols - :script, :script_basename, :script_dirname, :script_realpath, :script_stem - that directs inference of the process name. See
Pantheios::Util::ProcessUtil::derive_process_name -
SYNCHRONISED_SEVERITY_LOGGED [boolean] Determines whether the core protects the call to the underlying log-service's
severity_logged?with a mutex (which has a non-trivial cost).